==> gwt-bean-validators-engine-gwt-user-1.7.4.jar: de/knightsoftnet/validators/gwtuser/supersource/com/google/gwt/validation/client/impl/NodeImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package com.google.gwt.validation.client.impl;

import javax.validation.ElementKind;

/**
 * Dummy to fix compile problems as long validation-api 1.0 implementation is part of gwt.
 *
 * @author Manfred Tremmel
 *
 */
public class NodeImpl extends org.hibernate.validator.internal.engine.path.NodeImpl {

  private static final long serialVersionUID = -7481234506359509905L;

  protected NodeImpl(final String pname,
      final org.hibernate.validator.internal.engine.path.NodeImpl pparent, final boolean pindexable,
      final Integer pindex, final Object pkey, final ElementKind pkind,
      final Class<?>[] pparameterTypes, final Integer pparameterIndex, final Object pvalue) {
    super(pname, pparent, pindexable, pindex, pkey, pkind, pparameterTypes, pparameterIndex, pvalue,
        null, null);
  }
}

==> gwt-bean-validators-engine-gwt-user-1.9.0.jar: de/knightsoftnet/validators/gwtuser/supersource/com/google/gwt/validation/client/impl/NodeImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package com.google.gwt.validation.client.impl;

import javax.validation.ElementKind;

/**
 * Dummy to fix compile problems as long validation-api 1.0 implementation is part of gwt.
 *
 * @author Manfred Tremmel
 *
 */
public class NodeImpl extends org.hibernate.validator.internal.engine.path.NodeImpl {

  private static final long serialVersionUID = -7481234506359509905L;

  public NodeImpl(final String pname,
      final org.hibernate.validator.internal.engine.path.NodeImpl pparent, final boolean pindexable,
      final Integer pindex, final Object pkey, final ElementKind pkind,
      final Class<?>[] pparameterTypes, final Integer pparameterIndex, final Object pvalue) {
    super(pname, pparent, pindexable, pindex, pkey, pkind, pparameterTypes, pparameterIndex, pvalue,
        (Class<?>) null, (Integer) null);
  }
}
